/*
  Copyright (C) 2004-2005 SKYRIX Software AG

  This file is part of OpenGroupware.org.

  OGo is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  OGo is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with OGo; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __GDLContentStore_GCSFieldInfo_H__
#define __GDLContentStore_GCSFieldInfo_H__


/*
  GCSFieldInfo
  
  The field info inside an .ocs schema file.
  
  The field info objects are stored in an GCSFolderType.
*/

@class NSString, NSArray;

@interface GCSFieldInfo : NSObject
{
  NSString *columnName;
  NSString *sqlType;
  BOOL     allowsNull;
  BOOL     isPrimaryKey;
}

+ (NSArray *)fieldsForPropertyList:(NSArray *)_plist;
- (id)initWithPropertyList:(id)_plist;

/* accessors */

- (NSString *)columnName;
- (NSString *)sqlType;
- (BOOL)doesAllowNull;
- (BOOL)isPrimaryKey;

/* generating SQL */

- (NSString *)sqlCreateSection;

@end

#endif /* __GDLContentStore_GCSFieldInfo_H__ */
